@@ -170,7 +170,7 @@ function start_seahub () {
     check_init_admin;
 
     export DJANGO_SETTINGS_MODULE=seahub.settings
-    $PYTHON $gunicorn_exe seahub.wsgi:application -c "${gunicorn_conf}" --preload
+    $PYTHON $gunicorn_exe seahub.wsgi:application -c "${gunicorn_conf}" --preload &
 
     # Ensure seahub is started successfully
     sleep 5
@@ -252,9 +252,9 @@ function clear_sessions () {
 function stop_seahub () {
     if [[ -f ${pidfile} ]]; then
         echo "Stopping seahub ..."
-        pkill -f "$gunicorn_exe"
+        pkill -f "thirdpart/bin/gunicorn"
         sleep 1
-        if pgrep -f "$gunicorn_exe" 2>/dev/null 1>&2 ; then
+        if pgrep -f "thirdpart/bin/gunicorn" 2>/dev/null 1>&2 ; then
             echo 'Failed to stop seahub.'
             exit 1
         fi
