@@ -39,7 +39,11 @@
     "30 Days": "30 dienas",
     "7 Days": "7 dienas",
     "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
+    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
+    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
     "A file with the same name already exists in this folder.": "Datne ar t\u0101du pa\u0161u nosaukumu jau eksist\u0113 \u0161aj\u0101 map\u0113.",
+    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
+    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
     "API Token": "API Token",
     "API token is copied to the clipboard.": "API token is copied to the clipboard.",
     "About": "Par",
@@ -312,7 +316,6 @@
     "Dimensions": "Dimensions",
     "Direct download link": "Direct download link",
     "Direct download link is copied to the clipboard.": "Direct download link is copied to the clipboard.",
-    "Disable SAML user email / password login": "Disable SAML user email / password login",
     "Disable Two-Factor Authentication": "Atsp\u0113jot divfaktoru autentifik\u0101cija",
     "Disconnect": "Disconnect",
     "Discussion": "Diskusija",
@@ -467,7 +470,6 @@
     "Folder does not exist.": "Folder does not exist.",
     "Folders": "Mapes",
     "Force user to change password when account is newly added or reset by admin": "Force user to change password when account is newly added or reset by admin",
-    "Force user to use SSO login if SAML account is bound": "Force user to use SSO login if SAML account is bound",
     "Force user to use a strong password when sign up or change password.": "Force user to use a strong password when sign up or change password.",
     "Format": "Format",
     "Freeze Document": "Freeze Document",
@@ -563,7 +565,6 @@
     "Library": "Kr\u0101tuve",
     "Library Type": "Bibliot\u0113kas tips",
     "Library does not exist": "Bibliot\u0113ka nepast\u0101v",
-    "Library share permission not found.": "Library share permission not found.",
     "Limits": "Ierobe\u017eojumi",
     "Link": "Saite",
     "Link has been copied to clipboard": "Link has been copied to clipboard",
@@ -647,7 +648,6 @@
     "New PowerPoint File": "Jauna PowerPoint datne",
     "New SeaDoc File": "New SeaDoc File",
     "New Sub-department": "New Sub-department",
-    "New Wiki name": "New Wiki name",
     "New Word File": "New Word File",
     "New directories": "Jaunas mapes",
     "New file name": "New file name",
@@ -799,7 +799,6 @@
     "Pictures and videos": "Pictures and videos",
     "Platform": "Platforma",
     "Please check the network.": "L\u016bdzu p\u0101rbaudiet t\u012bkla piesl\u0113gumu",
-    "Please choose a .sdoczip file.": "Please choose a .sdoczip file.",
     "Please choose a .xlsx file.": "Please choose a .xlsx file.",
     "Please choose an image file.": "Please choose an image file.",
     "Please enter 1 or more character": "L\u016bdzu, ievadiet 1 vai vair\u0101k rakstz\u012bmes",
@@ -914,6 +913,7 @@
     "Search property": "Search property",
     "Search users": "Search users",
     "Search users...": "Mekl\u0113t lietot\u0101jus...",
+    "Searching...": "Mekl\u0113...",
     "Select": "Atlas\u012bt",
     "Select File": "Select File",
     "Select a department": "Select a department",
@@ -1299,6 +1299,7 @@
     "xxx records selected": "xxx records selected",
     "xxx rows are copied.": "xxx rows are copied.",
     "you can also press \u2190 ": "var spiest ar\u012b  \u2190 ",
+    "you can also press \u2192": "you can also press \u2192",
     "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
     "{file} and {n} other files": "{file} and {n} other files",
     "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
