@@ -23,23 +23,27 @@
     "(If left blank, owner will be admin)": "(Om det l\u00e4mnas blankt, kommer \u00e4garen bli admin)",
     "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)": "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)",
     "(at least {placeholder} characters)": "(\u00e5tminstone {placeholder} tecken)",
-    "(current notification)": "aktuellt systemmeddelande",
+    "(current notification)": "(aktuellt systemmeddelande)",
     "(current version)": "(nuvarande version)",
     "1 Year": "1 \u00c5r",
     "1 cell copied": "1 cell copied",
-    "1 filter": "1 filter",
+    "1 filter": "1 filtrering",
     "1 hidden property": "1 hidden property",
     "1 month ago": "1 m\u00e5nad sedan",
     "1 preset hidden property": "1 preset hidden property",
     "1 record selected": "1 record selected",
     "1 row is copied.": "1 row is copied.",
-    "1 sort": "1 sort",
+    "1 sort": "1 sortering",
     "1 week ago": "1 vecka sedan",
     "3 days ago": "3 dagar sedan",
     "30 Days": "30 Dagar",
     "7 Days": "7 Dagar",
     "A file is being uploaded. Are you sure you want to leave this page?": "En fil h\u00e5ller p\u00e5 att laddas upp. \u00c4r du s\u00e4ker p\u00e5 att du vill l\u00e4mna denna sida?",
+    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "En fil med namnet {upload_file_link} \u00e4r uppladdat till {uploaded_link}.",
+    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
     "A file with the same name already exists in this folder.": "En fil med samma namn existerar i denna mapp.",
+    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
+    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
     "API Token": "API Token",
     "API token is copied to the clipboard.": "API token \u00e4r kopierad till urklipp.",
     "About": "Om",
@@ -75,6 +79,7 @@
     "Add auto expiration": "L\u00e4gg till automatisk utg\u00e5ngsdatum",
     "Add cover": "Add cover",
     "Add custom permission": "Add custom permission",
+    "Add filter": "L\u00e4gg till filtrering",
     "Add group": "Add group",
     "Add group member": "L\u00e4gg till gruppmedlem",
     "Add icon": "Add icon",
@@ -84,6 +89,7 @@
     "Add option": "Add option",
     "Add password protection": "L\u00e4gg till l\u00f6senordsskydd",
     "Add permission": "Add permission",
+    "Add sort": "L\u00e4gg till sortering",
     "Add user": "L\u00e4gg till anv\u00e4ndare",
     "Add view": "Add view",
     "Added": "Tillagd",
@@ -100,11 +106,12 @@
     "All Groups": "Alla grupper",
     "All Notifications": "Alla systemmeddelanden",
     "All Public Links": "Alla Publika L\u00e4nkar",
+    "All comments": "Alla kommentarer",
     "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Till\u00e5t nya anv\u00e4ndarregistreringar. Kryssa ur f\u00f6r att hindra att vem som helst skapar ett nytt konto.",
     "An integer that is greater than 0 or equal to -2.": "En siffra som \u00e4r st\u00f6rre \u00e4n 0 eller lika med -2.",
     "An integer that is greater than or equal to 0.": "En siffra som \u00e4r st\u00f6rre \u00e4n eller lika med 0.",
     "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "En intern l\u00e4nk \u00e4r en l\u00e4nk till en fil eller mapp som kan \u00f6ppnas av en anv\u00e4ndare med l\u00e4s r\u00e4ttigheter till filen eller mappen.",
-    "And": "And",
+    "And": "Och",
     "Anonymous User": "Anonnym anv\u00e4ndare",
     "Another property has this property type": "Another property has this property type",
     "Another user is editing this file!": "Another user is editing this file!",
@@ -113,10 +120,11 @@
     "Are you sure to change group {placeholder} to department ?": "Are you sure to change group {placeholder} to department ?",
     "Are you sure to delete": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort",
     "Are you sure to delete ": "Are you sure to delete ",
+    "Are you sure to delete this comment?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort denna kommentar?",
+    "Are you sure to delete this reply?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort detta svar?",
     "Are you sure to revoke access of user {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort tilltr\u00e4de f\u00f6r anv\u00e4ndare {placeholder}?",
     "Are you sure you want to clear trash?": "\u00c4r du s\u00e4ker p\u00e5 att du vill t\u00f6mma papperskorgen?",
     "Are you sure you want to delete": "Are you sure you want to delete",
-    "Are you sure you want to delete %s ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort %s ?",
     "Are you sure you want to delete WebDAV password?": "Are you sure you want to delete WebDAV password?",
     "Are you sure you want to delete the notification ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort notifikationen?",
     "Are you sure you want to delete the selected share link(s) ?": "Are you sure you want to delete the selected share link(s) ?",
@@ -169,6 +177,7 @@
     "Cannot move parent page to child page": "Cannot move parent page to child page",
     "Capture information": "Capture information",
     "Capture time": "Capture time",
+    "Card": "Kort",
     "Certificate": "Certificate",
     "Change": "\u00c4ndra",
     "Change Password": "Byt L\u00f6senord",
@@ -191,9 +200,11 @@
     "Close (Esc)": "St\u00e4ng (Esc)",
     "Code": "Kod",
     "Collaborator": "Collaborator",
+    "Collaborators": "Deltagare",
     "Collapse all": "Collapse all",
     "Color space": "Color space",
     "Comment": "Kommentar",
+    "Comment details": "Kommentar detaljer",
     "Comments": "Kommentarer",
     "Community Edition": "Community Edition",
     "Compressed": "Compressed",
@@ -245,7 +256,7 @@
     "Created group {group_name}": "Skapade grupp {group_name}",
     "Created library": "Skapade katalog",
     "Created library {library_name} with {owner} as its owner": "Skapade katalog {library_name} med {owner} som \u00e4gare",
-    "Created time": "Created time",
+    "Created time": "Skapad tid",
     "Created {n} files": "Skapat {n} filer",
     "Creator": "Skapad av",
     "Current Connected Devices": "Nuvarande Anslutna Enheter",
@@ -320,7 +331,6 @@
     "Dimensions": "Dimensions",
     "Direct download link": "Direct download link",
     "Direct download link is copied to the clipboard.": "Direkt nedladdningsl\u00e4nk kopierat till urklipp.",
-    "Disable SAML user email / password login": "Disable SAML user email / password login",
     "Disable Two-Factor Authentication": "Avaktivera tv\u00e5faktorsautentisering",
     "Disconnect": "Avsluta",
     "Discussion": "Diskussion",
@@ -336,7 +346,7 @@
     "Don't replace": "Byt inte ut",
     "Don't send emails": "Skicka inga mail",
     "Done": "Done",
-    "Down": "Down",
+    "Down": "Ned",
     "Download": "Ladda ner",
     "Download an example file": "Ladda ner en exempelfil",
     "Download and upload": "Ladda ner och ladda upp",
@@ -470,7 +480,7 @@
     "File {file_link} has a new comment form user {author}.": "Filen {file_link} har en ny kommentar fr\u00e5n anv\u00e4ndaren {author}.",
     "Files": "Filer",
     "Files and folders": "Files and folders",
-    "Filter": "Filter",
+    "Filter": "Filtrera",
     "Filters": "Filters",
     "Find a tag": "Find a tag",
     "Find modifiers": "Find modifiers",
@@ -480,12 +490,12 @@
     "Folder does not exist.": "Mapp existerar inte",
     "Force Two-Factor Authentication": "Tvinga Tv\u00e5faktors Autensiering",
     "Force user to change password when account is newly added or reset by admin": "Tvinga anv\u00e4ndare att byta l\u00f6senord n\u00e4r ett konto lagts till eller \u00e5terst\u00e4llts av en administrat\u00f6r.",
-    "Force user to use SSO login if SAML account is bound": "Force user to use SSO login if SAML account is bound",
     "Force user to use a strong password when sign up or change password.": "Tvinga anv\u00e4ndare att anv\u00e4nda ett starkt l\u00f6senord n\u00e4r ett konto skapas eller l\u00f6senord byts.",
     "Format": "Format",
     "Freeze Document": "Freeze Document",
     "Freeze user account when failed login attempts exceed limit.": "L\u00e5s anv\u00e4ndarkonto n\u00e4r antal misslyckade inloggningar n\u00e5tt en gr\u00e4ns.",
     "Frozen by {name}": "Frozen by {name}",
+    "Full screen": "Fullsk\u00e4rm",
     "Gallery": "Gallery",
     "General information": "General information",
     "Generate": "Generera",
@@ -509,7 +519,7 @@
     "Handled": "Hanterad",
     "Help": "Hj\u00e4lp",
     "Hide": "D\u00f6lj",
-    "Hide all": "Hide all",
+    "Hide all": "D\u00f6lj alla",
     "Hide properties": "Hide properties",
     "History": "Historik",
     "History Setting": "Historik Inst\u00e4llning",
@@ -540,7 +550,7 @@
     "Internal link has been copied to clipboard": "Intern l\u00e4nk har blivit kopierad till urklipp",
     "Invalid destination path": "Felaktig destinationss\u00f6kv\u00e4g",
     "Invalid filename.": "Felaktigt filnamn.",
-    "Invalid filter": "Invalid filter",
+    "Invalid filter": "Ogiltig filtrering",
     "Invalid month, should be yyyymm.": "Felaktig m\u00e5nad, ska vara yyyymm.",
     "Invalid regular expression": "Invalid regular expression",
     "Invisible": "Invisible",
@@ -565,6 +575,7 @@
     "Last Access": "Senast Access",
     "Last Login": "Senast Inloggning",
     "Last Update": "Senaste uppdatering",
+    "Last modification": "Sista \u00e4ndring",
     "Last modified by": "Senast \u00e4ndrad av",
     "Last modified time": "Last modified time",
     "Last modifier": "Last modifier",
@@ -578,7 +589,6 @@
     "Library": "Katalog",
     "Library Type": "Katalogstyp",
     "Library can not be shared to owner.": "Katalogen kan inte delas till \u00e4garen.",
-    "Library share permission not found.": "Library share permission not found.",
     "Limits": "Begr\u00e4nsningar",
     "Link": "L\u00e4nk",
     "Link has been copied to clipboard": "L\u00e4nken har blivit kopierad till urklipp",
@@ -598,6 +608,7 @@
     "Long text": "Long text",
     "Manage group members": "Hantera gruppmedlemmar",
     "Manage members": "Manage members",
+    "Mark all as read": "Markera alla som l\u00e4sna",
     "Mark all read": "Markera alla l\u00e4sta",
     "Mark as resolved": "Markera som l\u00f6st",
     "Max": "Max",
@@ -662,13 +673,12 @@
     "New PowerPoint File": "Ny PowerPoint-fil",
     "New SeaDoc File": "New SeaDoc File",
     "New Sub-department": "Ny Underavdelning",
-    "New Wiki name": "New Wiki name",
     "New Word File": "Ny Word-fil",
     "New directories": "Nya kataloger",
     "New file name": "Nytt filnamn",
     "New files": "Nya filer",
     "New folder name": "Nytt mappnamn",
-    "New page": "New page",
+    "New page": "Ny sida",
     "New password": "Nytt l\u00f6senord",
     "New password cannot be the same as old password": "New password cannot be the same as old password",
     "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "Nytt l\u00f6senord har skickats till din mailadress {mail}. V\u00e4nligen kontrollera din maill\u00e5da. Om du inte har f\u00e5tt l\u00f6senordet, v\u00e4nligen kontrollera att din mailadress \u00e4r korrekt konfigurerad.",
@@ -677,10 +687,11 @@
     "New view": "New view",
     "Next": "N\u00e4sta",
     "Next (Right arrow key)": "N\u00e4sta (H\u00f6ger piltangent)",
+    "Next modification": "N\u00e4sta \u00e4ndring",
     "No Admin login logs": "Inga Admin login loggar",
     "No Admin operation logs": "Inga Admin \u00e5tg\u00e4rdsloggar",
     "No Wikis": "No Wikis",
-    "No changes": "No changes",
+    "No changes": "Inga \u00e4ndringar",
     "No collaborators": "No collaborators",
     "No collaborators available": "No collaborators available",
     "No comment yet.": "Inga kommentarer \u00e4nnu.",
@@ -690,7 +701,7 @@
     "No file": "No file",
     "No file access logs": "Inga fil\u00e5tkomstloggar",
     "No file update logs": "Inga filuppdateringsloggar",
-    "No filters": "No filters",
+    "No filters": "Inga filtreringar",
     "No folders shared": "Inga mappar delade",
     "No groupings applied to this view.": "No groupings applied to this view.",
     "No groups": "Inga grupper",
@@ -716,10 +727,11 @@
     "No public libraries": "Inga publika kataloger",
     "No record": "No record",
     "No result": "Inget resultat",
-    "No results": "No results",
+    "No results": "Inga resultat",
     "No results matching": "No results matching",
     "No share links": "Inga delningsl\u00e4nkar",
     "No shared libraries": "Inga delade kataloger",
+    "No sorts": "Inga sorteringar",
     "No sync errors": "Inga synkroniseringsfel",
     "No tags": "Inga taggar",
     "No terms and conditions": "Inga villkor",
@@ -773,7 +785,7 @@
     "Operations": "\u00c5tg\u00e4rder",
     "Optional": "Valfritt",
     "Options imported": "Options imported",
-    "Or": "Or",
+    "Or": "Eller",
     "Organization": "Organisation",
     "Organization Admin": "Organisationsadmin",
     "Organizations": "Organisationer",
@@ -783,6 +795,7 @@
     "Others": "Others",
     "Out of quota.": "Slut p\u00e5 kvoten.",
     "Outdated": "Outdated",
+    "Outline": "Kontur",
     "Owned Libraries": "\u00c4gda Kataloger",
     "Owner": "\u00c4gare",
     "Owner can use admin panel in an organization, must be a new account.": "\u00c4gare kan inte anv\u00e4nda adminpanelen i en organisation. M\u00e5ste vara ett nytt konto.",
@@ -816,7 +829,6 @@
     "Pictures and videos": "Pictures and videos",
     "Platform": "Plattform",
     "Please check the network.": "Kontrollera n\u00e4tverksanslutningen",
-    "Please choose a .sdoczip file.": "Please choose a .sdoczip file.",
     "Please choose a .xlsx file.": "V\u00e4nligen v\u00e4lj en .xlsx fil.",
     "Please choose an image file.": "V\u00e4nligen ange en bildfil.",
     "Please enter 1 or more character": "V\u00e4nligen ange 1 eller fler tecken",
@@ -843,7 +855,7 @@
     "Preview only": "F\u00f6rhandsgranska enbart",
     "Previous": "Tidigare",
     "Previous (Left arrow key)": "F\u00f6reg\u00e5ende (V\u00e4nster piltangent)",
-    "Print": "Print",
+    "Print": "Skriv ut",
     "Professional Edition": "Professional Edition",
     "Profile": "Profil",
     "Profile Setting": "Profilinst\u00e4llningar",
@@ -897,6 +909,7 @@
     "Reset library password": "\u00c5terst\u00e4ll katalogsl\u00f6senord",
     "ResetPwd": "ResetPwd",
     "Resetting user's password, please wait for a moment.": "\u00c5terst\u00e4ller anv\u00e4ndarens l\u00f6senord, v\u00e4nligen v\u00e4nta.",
+    "Resolved comments": "L\u00f6sta kommentarer",
     "Restore": "L\u00e4s tillbaka",
     "Restore Library": "\u00c5terst\u00e4ll Katalog",
     "Restored file": "\u00c5terst\u00e4llt fil",
@@ -904,6 +917,7 @@
     "Restored library": "\u00c5terst\u00e4llt katalog",
     "Restored {name}": "Restored {name}",
     "Restored {name} and {n} other items": "Restored {name} and {n} other items",
+    "Resubmit": "Skicka om",
     "Result": "Resultat",
     "Retry": "F\u00f6rs\u00f6k igen",
     "Retry All": "F\u00f6rs\u00f6k igen med Alla",
@@ -926,28 +940,30 @@
     "Search Libraries": "S\u00f6k Kataloger",
     "Search Organizations": "S\u00f6k Organisationer",
     "Search Users": "S\u00f6k Anv\u00e4ndare",
-    "Search collaborator": "Search collaborator",
+    "Search collaborator": "S\u00f6k kollegor",
     "Search collaborators": "Search collaborators",
+    "Search department": "S\u00f6k efter avdelning",
     "Search files": "Search files",
     "Search files in this library": "S\u00f6k efter filer i denna katalog",
     "Search groups": "S\u00f6k grupper",
     "Search groups by name": "S\u00f6k grupper med namn",
     "Search libraries by name or ID": "Search libraries by name or ID",
     "Search libraries by owner": "S\u00f6k kataloger med \u00e4gare",
-    "Search option": "Search option",
+    "Search option": "S\u00f6k efter alternativ",
     "Search organizations": "S\u00f6k organisationer",
     "Search property": "Search property",
     "Search users": "S\u00f6k anv\u00e4ndare",
     "Search users...": "S\u00f6k anv\u00e4ndare...",
+    "Searching...": "S\u00f6ker...",
     "Select File": "V\u00e4lj Fil",
     "Select a department": "V\u00e4lj en avdelning",
     "Select a user": "V\u00e4lj en anv\u00e4ndare",
     "Select a user as admin": "Select a user as admin",
     "Select all": "Select all",
-    "Select an option": "Select an option",
+    "Select an option": "V\u00e4lj ett alternativ",
     "Select collaborators": "Select collaborators",
     "Select libraries to share": "V\u00e4lj kataloger att dela",
-    "Select option(s)": "Select option(s)",
+    "Select option(s)": "V\u00e4lj alternativ(er)",
     "Select up to 50 files": "Select up to 50 files",
     "Send": "Skicka",
     "Send activation Email after user registration.": "Skicka aktiverings-mejl efter anv\u00e4ndarregistrering.",
@@ -1002,14 +1018,14 @@
     "Shared with me": "Delade med mig",
     "Show": "Visa",
     "Show Codes": "Visa Koder",
-    "Show all": "Show all",
+    "Show all": "Visa alla",
     "Show changes": "Show changes",
     "Side Nav Menu": "Sidomeny",
     "Single select": "Single select",
     "Site name used in email sending": "Sidnamn som anv\u00e4nds i mejlutskick",
     "Site title shown in a browser tab": "Sidtiteln som visas i en webbl\u00e4sartabb",
     "Size": "Storlek",
-    "Sort": "Sort",
+    "Sort": "Sortera",
     "Sort ascending": "Sort ascending",
     "Sort descending": "Sort descending",
     "Space Used": "Anv\u00e4nt utrymme",
@@ -1024,7 +1040,7 @@
     "Storage": "Utrymme",
     "Storage Backend": "Lagringsyta",
     "Storage Used": "Anv\u00e4nt Utrymme",
-    "Style": "Style",
+    "Style": "Stil",
     "Submit": "OK",
     "Success": "Lyckades",
     "Successfully added label(s) for library {placeholder}": "Lyckades l\u00e4gga till markering(ar) till katalogen {placeholder}",
@@ -1092,7 +1108,7 @@
     "System Info": "Systeminformation",
     "System settings updated": "System settings updated",
     "Table": "Tabell",
-    "Tag not found": "Tag not found",
+    "Tag not found": "Inga alternativ tillg\u00e4ngliga",
     "Tagged Files": "Taggade Filer",
     "Tags": "Taggar",
     "Team name": "Team name",
@@ -1193,13 +1209,14 @@
     "Unlink device": "Avl\u00e4nka enhet",
     "Unlock": "L\u00e5s upp",
     "Unpublish": "Avpublicera",
+    "Unresolved comments": "Ol\u00f6sta kommentarer",
     "Unselect": "Unselect",
     "Unshare": "Sluta dela",
     "Unshare Library": "Sluta dela bibliotek",
     "Unstar": "Ta bort favorit",
     "Untitled": "Untitled",
     "Unwatch File Changes": "Unwatch File Changes",
-    "Up": "Up",
+    "Up": "Upp",
     "Update": "Uppdatera",
     "Update Terms and Conditions": "Uppdatera villkor",
     "Update password": "Update password",
@@ -1299,12 +1316,12 @@
     "Zoom out": "Zooma ut",
     "all": "alla",
     "all members": "alla medlemmar",
-    "contains": "contains",
+    "contains": "Inneh\u00e5ller",
     "days": "dagar",
     "deleted": "borttagen",
     "deleted option": "deleted option",
     "details": "detaljer",
-    "does not contain": "does not contain",
+    "does not contain": "Inneh\u00e5ller inte",
     "email is required": "mailadress kr\u00e4vs",
     "freezed": "freezed",
     "has all of...": "has all of...",
@@ -1312,17 +1329,17 @@
     "has none of...": "has none of...",
     "icon": "ikon",
     "in all libraries": "in all libraries",
-    "include the current user": "include the current user",
-    "is": "is",
+    "include the current user": "Inkludera mig",
+    "is": "\u00c4r",
     "is after...": "is after...",
     "is any of...": "is any of...",
     "is before...": "is before...",
-    "is current user's ID": "is current user's ID",
-    "is empty": "is empty",
+    "is current user's ID": "\u00c4r nuvarande anv\u00e4ndar-ID",
+    "is empty": "Tom",
     "is exactly...": "is exactly...",
     "is none of...": "is none of...",
-    "is not": "is not",
-    "is not empty": "is not empty",
+    "is not": "\u00c4r inte",
+    "is not empty": "Icke tom",
     "is on or after...": "is on or after...",
     "is on or before...": "is on or before...",
     "is within...": "is within...",
@@ -1340,7 +1357,7 @@
     "selected": "selected",
     "show more": "visa mer",
     "size": "storlek",
-    "sorts": "sorts",
+    "sorts": "Sorteringar",
     "starred": "favorit skapad",
     "state": "tillst\u00e5nd",
     "successfully added user %s.": "lyckades l\u00e4gga till anv\u00e4ndare %s.",
@@ -1352,6 +1369,7 @@
     "xxx records": "xxx records",
     "xxx records selected": "xxx records selected",
     "xxx rows are copied.": "xxx rows are copied.",
+    "you can also press \u2192": "du kan ocks\u00e5 trycka \u2192",
     "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
     "{file} and {n} other files": "{file} och {n} andra filer",
     "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} dagar",
